==> moodle-1.6.3p0.tgz: moodle/filter/activitynames/filter.php <==
<?php // $Id: filter.php,v 1.16 2006/01/11 15:11:00 stronk7 Exp $
    //This function provides automatic linking to
    //activities when its name (title) is found inside every Moodle text
    //It's based in the glosssary filter by Williams Castillo
    //Modifications by stronk7.

    function activitynames_filter($courseid, $text) {

        global $CFG;

        static $activitylist;

        if (empty($courseid)) {
            $courseid = SITEID;
        }

        /// It may be cached

        if (empty($activitylist)) {

            $course = get_record("course","id",$courseid);
            $modinfo = unserialize($course->modinfo);

            if (!empty($modinfo)) {

                $activitylist = array();      /// We will store all the activities here

                //Sort modinfo by name length
                usort($modinfo,'comparemodulenamesbylength');

                foreach ($modinfo as $activity) {
                    //Exclude labels and hidden items
                    if ($activity->mod != "label" && $activity->visible) {
                        $title = trim(strip_tags(urldecode($activity->name)));
                        /// Avoid empty or unlinkable activity names
                        if (!empty($title)) {
                            $title = str_replace('"', "'", $title);
                            $href_tag_begin = "<a class=\"autolink\" title=\"$title\" href=\"$CFG->wwwroot/mod/$activity->mod/view.php?id=$activity->cm\" target=\"$CFG->framename\">";
                            $currentname = urldecode($activity->name);
                            if ($currentname = trim($currentname)) {
                                $activitylist[] = new filterobject($currentname, $href_tag_begin, '</a>', false, true);
                            }
                        }
                    }
                }
            }
        }

        return $text = filter_phrases ($text, $activitylist);
    }



    //This function is used to order module names from longer to shorter
    function comparemodulenamesbylength($a, $b)  {
        if (strlen($a->name) == strlen($b->name)) {
            return 0;
        }
        return (strlen($a->name) < strlen($b->name)) ? 1 : -1;
    }
?>

==> moodle-1.7.tgz: moodle/filter/activitynames/filter.php <==
<?php // $Id: filter.php,v 1.17 2006/09/04 21:12:38 stronk7 Exp $
    //This function provides automatic linking to
    //activities when its name (title) is found inside every Moodle text
    //It's based in the glosssary filter by Williams Castillo
    //Modifications by stronk7.

    function activitynames_filter($courseid, $text) {

        global $CFG;

        static $activitylist;

        if (empty($courseid)) {
            $courseid = SITEID;
        }

        /// It may be cached

        if (empty($activitylist)) {

            $course = get_record("course","id",$courseid);
        /// Casting $course->modinfo to string prevents one notice when the field is null
            $modinfo = unserialize((string)$course->modinfo);

            if (!empty($modinfo)) {

                $activitylist = array();      /// We will store all the activities here

                //Sort modinfo by name length
                usort($modinfo,'comparemodulenamesbylength');

                foreach ($modinfo as $activity) {
                    //Exclude labels and hidden items
                    if ($activity->mod != "label" && $activity->visible) {
                        $title = trim(strip_tags(urldecode($activity->name)));
                        /// Avoid empty or unlinkable activity names
                        if (!empty($title)) {
                            $title = str_replace('"', "'", $title);
                            $href_tag_begin = "<a class=\"autolink\" title=\"$title\" href=\"$CFG->wwwroot/mod/$activity->mod/view.php?id=$activity->cm\" target=\"$CFG->framename\">";
                            $currentname = urldecode($activity->name);
                            if ($currentname = trim($currentname)) {
                                $activitylist[] = new filterobject($currentname, $href_tag_begin, '</a>', false, true);
                            }
                        }
                    }
                }
            }
        }

        return $text = filter_phrases ($text, $activitylist);
    }



    //This function is used to order module names from longer to shorter
    function comparemodulenamesbylength($a, $b)  {
        if (strlen($a->name) == strlen($b->name)) {
            return 0;
        }
        return (strlen($a->name) < strlen($b->name)) ? 1 : -1;
    }
?>
